=======
Credits
=======

Development Lead
----------------

* Julien Roussel <jroussel@quantmetry.com>

Maintainers
------------

* Mikail Duran <mduran@quantmetry.com>
* Anh Khoa Ngo Ho <angoho@quantmetry.com>
* Guillaume Saës <gsaes@quantmetry.com>

Contributors
------------

* Hong-Lan Botterman
* Firas Dakhli
* Rima Hajou
* Vianey Taquet
